.. Audio Purifier documentation master file, created by
   sphinx-quickstart on Sat Sep 30 22:12:25 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Audio Purifier's documentation!
==========================================

**Audio Purifier** is a utility package that enables silent parts
removal from audio, exporting as new files. Inspired by
`faster-whisper <https://github.com/guillaumekln/faster-whisper/>`_, which
used SileroVAD for audio processing.

.. note::

   This project is under active development.

Contents
--------

.. toctree::
   Home <self>
   usage
   reference/index
